# -*- coding: utf-8 -*-
from __future__ import unicode_literals

TUS_RESUMABLE_FIELD_NAME = 'tus_resumable'

UPLOAD_DEFER_LENGTH_FIELD_NAME = 'tus_upload_defer_length'
UPLOAD_LENGTH_FIELD_NAME = 'tus_upload_length'
UPLOAD_OFFSET_NAME = 'tus_upload_offset'
UPLOAD_METADATA_FIELD_NAME = 'tus_upload_metadata'
UPLOAD_CHECKSUM_FIELD_NAME = 'tus_upload_checksum'
